/*
 *  Copyright 2010 Felix Roethenbacher
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package ch.syabru.nagios.broker;

import org.apache.commons.daemon.Daemon;
import org.apache.commons.daemon.DaemonContext;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.BeansException;
import org.springframework.context.support.AbstractApplicationContext;
import org.springframework.context.support.ClassPathXmlApplicationContext;

import ch.syabru.nagios.broker.impl.NagiosMessageBrokerImpl;

/**
 * Nagios message broker bootstrap implementation.
 *
 * @author Felix Roethenbacher
 *
 */
public class Bootstrap implements Daemon {
    private static final Logger logger =
        LoggerFactory.getLogger(Bootstrap.class);

    private NagiosMessageBrokerImpl msgBroker;

    /**
     * Main method.
     * @param args Command line arguments.
     */
    public static void main(String[] args) {
        final Bootstrap bootstrap = new Bootstrap();
        Thread terminator = new Thread() {
            public void run() {
                try {
                    // Return will terminate application.
                    if (System.in.read() != 10) {
                        Thread.sleep(100);
                    } else {
                        bootstrap.stop();
                    }
                } catch (Exception e) {
                    logger.error("Error in termination loop", e);
                }
            };
        };
        terminator.start();
        try {
            bootstrap.createApplicationContext();
            bootstrap.start();
        } catch (Exception e) {
            e.printStackTrace();
            System.exit(-1);
        }
    }

    @Override
    public void start() throws Exception {
        msgBroker.start();
    }

    @Override
    public void stop() throws Exception {
        msgBroker.stop();
    }

    @Override
    public void destroy() {
    }

    @Override
    public void init(DaemonContext ctx) throws Exception {
        createApplicationContext();
    }

    /**
     * Create Spring application context.
     */
    private void createApplicationContext() {
        try {
            AbstractApplicationContext context =
                new ClassPathXmlApplicationContext(new String[] {
                        "META-INF/spring/applicationContext*.xml"});
            context.registerShutdownHook();
            msgBroker = (NagiosMessageBrokerImpl) context.getBean(
                    "nagiosMessageBroker");
            msgBroker.setIsDaemon(true);
        } catch (BeansException e) {
            logger.error("Error starting application", e);
            System.exit(1);
        }
    }
}
