/*
 *  Copyright 2010 Felix Roethenbacher
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package ch.syabru.nagios.broker;

import java.util.Calendar;

import javax.annotation.PostConstruct;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

/**
 * Version.
 *
 * Loads version information from properties file.
 *
 * @author Felix Roethenbacher
 *
 */
public class Version {
    private final Logger logger = LoggerFactory.getLogger(Version.class);

    private String version;
    private String inceptionYear;
    private String copyright;

    /**
     * Init method.
     */
    @PostConstruct
    public void init() {
        int year = Calendar.getInstance().get(Calendar.YEAR);
        if (inceptionYear != null &&
                inceptionYear.equals(Integer.valueOf(year).toString()))
        {
            copyright = "Copyright " + year + " Felix Roethenbacher";
        } else {
            copyright = "Copyright " + inceptionYear + " - " + year +
                " Felix Roethenbacher";
        }
        logger.info("Syabru Nagios Message Broker - Version {}", version);
        logger.info(copyright);
    }

    public String getVersion() {
        return version;
    }

    public void setVersion(String version) {
        this.version = version;
    }

    public String getCopyright() {
        return copyright;
    }

    public void setInceptionYear(String inceptionYear) {
        this.inceptionYear = inceptionYear;
    }

}
