/*
 *  Copyright 2010 Felix Roethenbacher
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package ch.syabru.nagios.broker.impl;

import java.io.FileWriter;
import java.io.IOException;
import java.io.Writer;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Required;
import org.springframework.core.io.Resource;

import ch.syabru.nagios.broker.ExternalCommand;
import ch.syabru.nagios.broker.ExternalCommandHandler;
import ch.syabru.nagios.broker.ExternalCommandHandlerException;

/**
 * External command handler implementation.
 *
 * @author Felix Roethenbacher
 *
 */
public class ExternalCommandHandlerImpl implements ExternalCommandHandler {
    private final Logger logger = LoggerFactory.getLogger(this.getClass());

    private Resource nagiosCommandFile;

    @Override
    public void submitExternalCommand(ExternalCommand command)
    throws ExternalCommandHandlerException
    {
        if (!nagiosCommandFile.exists())
            throw new ExternalCommandHandlerException(
                    "Nagios external command file not found [" +
                    nagiosCommandFile.getDescription() + "]");
        Writer writer = null;
        try {
            writer = new FileWriter(
                    nagiosCommandFile.getFile(), true);
            command.writeCommand(writer);
            writer.flush();
        } catch (IOException e) {
            throw new ExternalCommandHandlerException(
                    "Error submitting external command", e);
        } finally {
            if (writer != null) {
                try {
                    writer.close();
                } catch (IOException e) {
                    logger.error("Error closing writer", e);
                }
            }
        }
    }

    @Required
    public void setNagiosCommandFile(Resource nagiosCommandFile) {
        this.nagiosCommandFile = nagiosCommandFile;
    }
}
