/*
 *  Copyright 2010 Felix Roethenbacher
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package ch.syabru.nagios.broker.impl;

import org.apache.commons.lang.Validate;

import ch.syabru.nagios.broker.ExternalCommand;
import ch.syabru.nagios.broker.ExternalCommandFactory;

/**
 * Process service check result command factory.
 *
 * @author Felix Roethenbacher
 *
 */
public class ProcessServiceCheckResultCommandFactory
implements ExternalCommandFactory
{
    private String hostName;
    private String serviceDescription;
    private int returnCode;
    private String pluginOutput;

    /**
     * C'tor.
     * @param hostName Host name.
     * @param serviceDescription Service description.
     * @param returnCode Return code.
     * @param pluginOutput Plugin output.
     */
    public ProcessServiceCheckResultCommandFactory(String hostName,
            String serviceDescription, int returnCode, String pluginOutput)
    {
        Validate.notNull(hostName, "hostName must not be null");
        Validate.notNull(serviceDescription,
                "serviceDescription must not be null");
        Validate.notNull(returnCode, "returnCode must not be null");
        Validate.notNull(pluginOutput, "pluginOutput must not be null");
        this.hostName = hostName;
        this.serviceDescription = serviceDescription;
        this.returnCode = returnCode;
        this.pluginOutput = pluginOutput;
    }

    @Override
    public ExternalCommand createCommand() {
        return new ProcessServiceCheckResultCommand(
                hostName, serviceDescription, returnCode, pluginOutput);
    }

}
