/*
 *  Copyright 2010 Felix Roethenbacher
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package ch.syabru.nagios.broker.impl;

import java.util.Calendar;
import java.util.Date;

import org.apache.commons.lang.Validate;

import ch.syabru.nagios.broker.ExternalCommand;
import ch.syabru.nagios.broker.ExternalCommandFactory;

/**
 * Schedule forced service check command factory.
 *
 * @author Felix Roethenbacher
 *
 */
public class ScheduleForcedServiceCheckCommandFactory
implements ExternalCommandFactory
{
    private String hostName;
    private String serviceDescription;
    private Date checkTime;
    private int delaySeconds;

    /**
     * C'tor.
     * @param hostName Host name.
     * @param serviceDescription Service description.
     * @param checkTime Absolute check time, set to null for current time.
     * @param delaySeconds Delay in seconds. Set to 0 for immediate check.
     */
    public ScheduleForcedServiceCheckCommandFactory(String hostName,
            String serviceDescription, Date checkTime, int delaySeconds)
    {
        Validate.notNull(hostName, "hostName must not be null");
        Validate.notNull(serviceDescription,
                "serviceDescription must not be null");
        this.hostName = hostName;
        this.serviceDescription = serviceDescription;
        this.checkTime = checkTime;
        this.delaySeconds = delaySeconds;
    }

    @Override
    public ExternalCommand createCommand() {
        Calendar checkTimeCal = Calendar.getInstance();
        if (checkTime != null)
            checkTimeCal.setTime(checkTime);
        checkTimeCal.add(Calendar.SECOND, delaySeconds);
        return new ScheduleForcedServiceCheckCommand(
                hostName, serviceDescription, checkTimeCal.getTime());
    }

}
